@@ -34,10 +34,11 @@ null_distn <- fli_small %>%
   hypothesize(null = "point", mu = 10) %>%
   generate(reps = 1000) %>%
   calculate(stat = "mean")
-null_distn %>% 
-  visualize(obs_stat = x_bar, direction = "two_sided")
+
+visualize(null_distn) +
+  shade_p_value(obs_stat = x_bar, direction = "two_sided")
 null_distn %>%
-  get_pvalue(obs_stat = x_bar, direction = "two_sided")
+  get_p_value(obs_stat = x_bar, direction = "two_sided")
 
 ## ------------------------------------------------------------------------
 ( t_bar <- fli_small %>%
@@ -50,10 +51,11 @@ null_distn <- fli_small %>%
   hypothesize(null = "point", mu = 8) %>%
   generate(reps = 1000) %>%
   calculate(stat = "t")
-null_distn %>% 
-  visualize(obs_stat = t_bar, direction = "two_sided")
+
+visualize(null_distn) +
+  shade_p_value(obs_stat = t_bar, direction = "two_sided")
 null_distn %>%
-  get_pvalue(obs_stat = t_bar, direction = "two_sided")
+  get_p_value(obs_stat = t_bar, direction = "two_sided")
 
 ## ------------------------------------------------------------------------
 ( x_tilde <- fli_small %>%
@@ -66,10 +68,11 @@ null_distn <- fli_small %>%
   hypothesize(null = "point", med = -1) %>% 
   generate(reps = 1000) %>% 
   calculate(stat = "median")
-null_distn %>% 
-  visualize(obs_stat = x_tilde, direction = "two_sided")
+
+visualize(null_distn) +
+  shade_p_value(obs_stat = x_tilde, direction = "two_sided")
 null_distn %>%
-  get_pvalue(obs_stat = x_tilde, direction = "two_sided")
+  get_p_value(obs_stat = x_tilde, direction = "two_sided")
 
 ## ------------------------------------------------------------------------
 ( p_hat <- fli_small %>%
@@ -82,10 +85,11 @@ null_distn <- fli_small %>%
   hypothesize(null = "point", p = .5) %>%
   generate(reps = 1000) %>%
   calculate(stat = "prop")
-null_distn %>% 
-  visualize(obs_stat = p_hat, direction = "two_sided")
+
+visualize(null_distn) +
+  shade_p_value(obs_stat = p_hat, direction = "two_sided")
 null_distn %>%
-  get_pvalue(obs_stat = p_hat, direction = "two_sided")
+  get_p_value(obs_stat = p_hat, direction = "two_sided")
 
 ## ------------------------------------------------------------------------
 null_distn <- fli_small %>%
@@ -106,10 +110,11 @@ null_distn <- fli_small %>%
   hypothesize(null = "independence") %>% 
   generate(reps = 1000) %>% 
   calculate(stat = "diff in props", order = c("winter", "summer"))
-null_distn %>% 
-  visualize(obs_stat = d_hat, direction = "two_sided")
+
+visualize(null_distn) +
+  shade_p_value(obs_stat = d_hat, direction = "two_sided")
 null_distn %>%
-  get_pvalue(obs_stat = d_hat, direction = "two_sided")
+  get_p_value(obs_stat = d_hat, direction = "two_sided")
 
 ## ------------------------------------------------------------------------
 ( z_hat <- fli_small %>% 
@@ -122,10 +127,11 @@ null_distn <- fli_small %>%
   hypothesize(null = "independence") %>% 
   generate(reps = 1000) %>% 
   calculate(stat = "z", order = c("winter", "summer"))
-null_distn %>% 
-  visualize(obs_stat = z_hat, direction = "two_sided")
+
+visualize(null_distn) +
+  shade_p_value(obs_stat = z_hat, direction = "two_sided")
 null_distn %>%
-  get_pvalue(obs_stat = z_hat, direction = "two_sided")
+  get_p_value(obs_stat = z_hat, direction = "two_sided")
 
 ## ------------------------------------------------------------------------
 ( Chisq_hat <- fli_small %>%
@@ -141,10 +147,11 @@ null_distn <- fli_small %>%
               p = c("EWR" = .33, "JFK" = .33, "LGA" = .34)) %>% 
   generate(reps = 1000, type = "simulate") %>% 
   calculate(stat = "Chisq")
-null_distn %>% 
-  visualize(obs_stat = Chisq_hat, direction = "greater")
+
+visualize(null_distn) +
+  shade_p_value(obs_stat = Chisq_hat, direction = "greater")
 null_distn %>%
-  get_pvalue(obs_stat = Chisq_hat, direction = "greater")
+  get_p_value(obs_stat = Chisq_hat, direction = "greater")
 
 ## ------------------------------------------------------------------------
 ( Chisq_hat <- fli_small %>%
@@ -157,10 +164,11 @@ null_distn <- fli_small %>%
   hypothesize(null = "independence") %>% 
   generate(reps = 1000, type = "permute") %>% 
   calculate(stat = "Chisq")
-null_distn %>% 
-  visualize(obs_stat = Chisq_hat, direction = "greater")
+
+visualize(null_distn) +
+  shade_p_value(obs_stat = Chisq_hat, direction = "greater")
 null_distn %>%
-  get_pvalue(obs_stat = Chisq_hat, direction = "greater")
+  get_p_value(obs_stat = Chisq_hat, direction = "greater")
 
 ## ------------------------------------------------------------------------
 ( d_hat <- fli_small %>% 
@@ -173,10 +181,11 @@ null_distn <- fli_small %>%
   hypothesize(null = "independence") %>%
   generate(reps = 1000, type = "permute") %>%
   calculate(stat = "diff in means", order = c("summer", "winter"))
-null_distn %>% 
-  visualize(obs_stat = d_hat, direction = "two_sided")
+
+visualize(null_distn) +
+  shade_p_value(obs_stat = d_hat, direction = "two_sided")
 null_distn %>%
-  get_pvalue(obs_stat = d_hat, direction = "two_sided")
+  get_p_value(obs_stat = d_hat, direction = "two_sided")
 
 ## ------------------------------------------------------------------------
 ( t_hat <- fli_small %>% 
@@ -189,10 +198,11 @@ null_distn <- fli_small %>%
   hypothesize(null = "independence") %>%
   generate(reps = 1000, type = "permute") %>%
   calculate(stat = "t", order = c("summer", "winter"))
-null_distn %>% 
-  visualize(obs_stat = t_hat, direction = "two_sided")
+
+visualize(null_distn) +
+  shade_p_value(obs_stat = t_hat, direction = "two_sided")
 null_distn %>%
-  get_pvalue(obs_stat = t_hat, direction = "two_sided")
+  get_p_value(obs_stat = t_hat, direction = "two_sided")
 
 ## ------------------------------------------------------------------------
 ( d_hat <- fli_small %>% 
@@ -206,10 +216,11 @@ null_distn <- fli_small %>%
   hypothesize(null = "independence") %>%
   generate(reps = 1000, type = "permute") %>%
   calculate(stat = "diff in medians", order = c("summer", "winter"))
-null_distn %>% 
-  visualize(obs_stat = d_hat, direction = "two_sided")
+
+visualize(null_distn) +
+  shade_p_value(obs_stat = d_hat, direction = "two_sided")
 null_distn %>%
-  get_pvalue(obs_stat = d_hat, direction = "two_sided")
+  get_p_value(obs_stat = d_hat, direction = "two_sided")
 
 ## ------------------------------------------------------------------------
 ( F_hat <- fli_small %>% 
@@ -222,10 +233,11 @@ null_distn <- fli_small %>%
    hypothesize(null = "independence") %>%
    generate(reps = 1000, type = "permute") %>%
    calculate(stat = "F")
-null_distn %>% 
-  visualize(obs_stat = F_hat, direction = "greater")
+
+visualize(null_distn) +
+  shade_p_value(obs_stat = F_hat, direction = "greater")
 null_distn %>%
-  get_pvalue(obs_stat = F_hat, direction = "greater")
+  get_p_value(obs_stat = F_hat, direction = "greater")
 
 ## ------------------------------------------------------------------------
 ( slope_hat <- fli_small %>% 
@@ -238,10 +250,11 @@ null_distn <- fli_small %>%
    hypothesize(null = "independence") %>%
    generate(reps = 1000, type = "permute") %>%
    calculate(stat = "slope")
-null_distn %>% 
-  visualize(obs_stat = slope_hat, direction = "two_sided")
+
+visualize(null_distn) +
+  shade_p_value(obs_stat = slope_hat, direction = "two_sided")
 null_distn %>%
-  get_pvalue(obs_stat = slope_hat, direction = "two_sided")
+  get_p_value(obs_stat = slope_hat, direction = "two_sided")
 
 ## ------------------------------------------------------------------------
 ( correlation_hat <- fli_small %>% 
@@ -254,10 +267,11 @@ null_distn <- fli_small %>%
    hypothesize(null = "independence") %>%
    generate(reps = 1000, type = "permute") %>%
    calculate(stat = "correlation")
-null_distn %>% 
-  visualize(obs_stat = correlation_hat, direction = "two_sided")
+
+visualize(null_distn) +
+  shade_p_value(obs_stat = correlation_hat, direction = "two_sided")
 null_distn %>%
-  get_pvalue(obs_stat = correlation_hat, direction = "two_sided")
+  get_p_value(obs_stat = correlation_hat, direction = "two_sided")
 
 ## ----echo=FALSE, eval=FALSE----------------------------------------------
 #  # **Standardized observed stat**
@@ -271,10 +285,11 @@ null_distn %>%
 #     hypothesize(null = "independence") %>%
 #     generate(reps = 1000, type = "permute") %>%
 #     calculate(stat = "t")
+#  
+#  visualize(null_distn) +
+#    shade_p_value(obs_stat = t_hat, direction = "two_sided")
 #  null_distn %>%
-#    visualize(obs_stat = t_hat, direction = "two_sided")
-#  null_distn %>%
-#    get_pvalue(obs_stat = t_hat, direction = "two_sided")
+#    get_p_value(obs_stat = t_hat, direction = "two_sided")
 
 ## ------------------------------------------------------------------------
 ( x_bar <- fli_small %>% 
@@ -287,9 +302,13 @@ boot <- fli_small %>%
    generate(reps = 1000, type = "bootstrap") %>%
    calculate(stat = "mean")
 ( percentile_ci <- get_ci(boot) )
-boot %>% visualize(endpoints = percentile_ci, direction = "between")
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = percentile_ci)
 ( standard_error_ci <- get_ci(boot, type = "se", point_estimate = x_bar) )
-boot %>% visualize(endpoints = standard_error_ci, direction = "between")
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = standard_error_ci)
 
 ## ------------------------------------------------------------------------
 ( t_hat <- fli_small %>% 
@@ -302,9 +321,13 @@ boot <- fli_small %>%
    generate(reps = 1000, type = "bootstrap") %>%
    calculate(stat = "t")
 ( percentile_ci <- get_ci(boot) )
-boot %>% visualize(endpoints = percentile_ci, direction = "between")
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = percentile_ci)
 ( standard_error_ci <- get_ci(boot, type = "se", point_estimate = t_hat) )
-boot %>% visualize(endpoints = standard_error_ci, direction = "between")
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = standard_error_ci)
 
 ## ------------------------------------------------------------------------
 ( p_hat <- fli_small %>% 
@@ -317,9 +340,13 @@ boot <- fli_small %>%
  generate(reps = 1000, type = "bootstrap") %>%
  calculate(stat = "prop")
 ( percentile_ci <- get_ci(boot) )
-boot %>% visualize(endpoints = percentile_ci, direction = "between")
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = percentile_ci)
 ( standard_error_ci <- get_ci(boot, type = "se", point_estimate = p_hat) )
-boot %>% visualize(endpoints = standard_error_ci, direction = "between")
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = standard_error_ci)
 
 ## ------------------------------------------------------------------------
 ( d_hat <- fli_small %>%
@@ -332,9 +359,13 @@ boot <- fli_small %>%
    generate(reps = 1000, type = "bootstrap") %>%
    calculate(stat = "diff in means", order = c("summer", "winter"))
 ( percentile_ci <- get_ci(boot) )
-boot %>% visualize(endpoints = percentile_ci, direction = "between")
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = percentile_ci)
 ( standard_error_ci <- get_ci(boot, type = "se", point_estimate = d_hat) )
-boot %>% visualize(endpoints = standard_error_ci, direction = "between")
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = standard_error_ci)
 
 ## ------------------------------------------------------------------------
 ( t_hat <- fli_small %>%
@@ -347,9 +378,13 @@ boot <- fli_small %>%
    generate(reps = 1000, type = "bootstrap") %>%
    calculate(stat = "t", order = c("summer", "winter"))
 ( percentile_ci <- get_ci(boot) )
-boot %>% visualize(endpoints = percentile_ci, direction = "between")
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = percentile_ci)
 ( standard_error_ci <- get_ci(boot, type = "se", point_estimate = t_hat) )
-boot %>% visualize(endpoints = standard_error_ci, direction = "between")
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = standard_error_ci)
 
 ## ------------------------------------------------------------------------
 ( d_hat <- fli_small %>% 
@@ -362,9 +397,13 @@ boot <- fli_small %>%
   generate(reps = 1000, type = "bootstrap") %>% 
   calculate(stat = "diff in props", order = c("summer", "winter"))
 ( percentile_ci <- get_ci(boot) )
-boot %>% visualize(endpoints = percentile_ci, direction = "between")
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = percentile_ci)
 ( standard_error_ci <- get_ci(boot, type = "se", point_estimate = d_hat) )
-boot %>% visualize(endpoints = standard_error_ci, direction = "between")
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = standard_error_ci)
 
 ## ------------------------------------------------------------------------
 ( z_hat <- fli_small %>% 
@@ -377,9 +416,13 @@ boot <- fli_small %>%
   generate(reps = 1000, type = "bootstrap") %>% 
   calculate(stat = "z", order = c("summer", "winter"))
 ( percentile_ci <- get_ci(boot) )
-boot %>% visualize(endpoints = percentile_ci, direction = "between")
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = percentile_ci)
 ( standard_error_ci <- get_ci(boot, type = "se", point_estimate = z_hat) )
-boot %>% visualize(endpoints = standard_error_ci, direction = "between")
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = standard_error_ci)
 
 ## ------------------------------------------------------------------------
 ( slope_hat <- fli_small %>% 
@@ -392,9 +435,13 @@ boot <- fli_small %>%
    generate(reps = 1000, type = "bootstrap") %>%
    calculate(stat = "slope")
 ( percentile_ci <- get_ci(boot) )
-boot %>% visualize(endpoints = percentile_ci, direction = "between")
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = percentile_ci)
 ( standard_error_ci <- get_ci(boot, type = "se", point_estimate = slope_hat) )
-boot %>% visualize(endpoints = standard_error_ci, direction = "between") 
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = standard_error_ci)
 
 ## ------------------------------------------------------------------------
 ( correlation_hat <- fli_small %>% 
@@ -407,10 +454,14 @@ boot <- fli_small %>%
    generate(reps = 1000, type = "bootstrap") %>%
    calculate(stat = "correlation")
 ( percentile_ci <- get_ci(boot) )
-boot %>% visualize(endpoints = percentile_ci, direction = "between")
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = percentile_ci)
 ( standard_error_ci <- get_ci(boot, type = "se", 
                             point_estimate = correlation_hat) )
-boot %>% visualize(endpoints = standard_error_ci, direction = "between")  
+
+visualize(boot) +
+  shade_confidence_interval(endpoints = standard_error_ci)
 
 ## ----eval=FALSE, echo=FALSE----------------------------------------------
 #  # **Point estimate**
@@ -424,7 +475,11 @@ boot %>% visualize(endpoints = standard_error_ci, direction = "between")
 #     generate(reps = 1000, type = "bootstrap") %>%
 #     calculate(stat = "t")
 #  ( percentile_ci <- get_ci(boot) )
-#  boot %>% visualize(endpoints = percentile_ci, direction = "between")
+#  
+#  visualize(boot) +
+#    shade_confidence_interval(endpoints = percentile_ci)
 #  ( standard_error_ci <- get_ci(boot, type = "se", point_estimate = t_hat) )
-#  boot %>% visualize(endpoints = standard_error_ci, direction = "between")
+#  
+#  visualize(boot) +
+#    shade_confidence_interval(endpoints = standard_error_ci)
 
